#!/usr/bin/env python3
#exonware/xwsystem/tests/3.advance/conftest.py
"""
Pytest configuration for advance tests.
Company: eXonware.com
Author: eXonware Backend Team
Email: connect@exonware.com
Version: 0.0.1.388
Generation Date: 01-Nov-2025
"""

import pytest
import sys
from pathlib import Path
# Ensure src is in path
src_path = Path(__file__).parent.parent.parent / "src"
if str(src_path) not in sys.path:
    sys.path.insert(0, str(src_path))
