#exonware/xwsystem/tests/0.core/validation/__init__.py
"""
Core Validation Tests
Tests data validation, declarative models, and validation utilities.
Focuses on the main validation functionality and real-world validation scenarios.
"""
