#exonware/xwsystem/tests/0.core/monitoring/__init__.py
"""
Core Monitoring Tests
Tests performance monitoring, memory monitoring, circuit breakers, and metrics.
Focuses on the main monitoring functionality and real-world monitoring scenarios.
"""
