"""
#exonware/xwsystem/src/exonware/xwsystem/defs.py
Package-level definitions (constants, enums, TypedDicts) for xwsystem.
Company: eXonware.com
Author: eXonware Backend Team
Email: connect@exonware.com
Version: 0.1.0.11
Last Updated: 29-Jan-2026
"""

from __future__ import annotations
__all__: list[str] = []
